diff libvo/gl_common.c @ 21201:2c1b7fe05973

Avoid void * arithmetic
author reimar
date Sat, 25 Nov 2006 13:34:55 +0000
parents a95ed9a69caf
children 2d3fdf94a50c
line wrap: on
line diff
--- a/libvo/gl_common.c	Sat Nov 25 13:03:51 2006 +0000
+++ b/libvo/gl_common.c	Sat Nov 25 13:34:55 2006 +0000
@@ -473,7 +473,7 @@
  * \param target texture target, usually GL_TEXTURE_2D
  * \param format OpenGL format of data
  * \param type OpenGL type of data
  * \param data data to upload
  * \param stride data stride
  * \param x x offset in texture
  * \param y y offset in texture
@@ -483,8 +483,9 @@
  * \ingroup gltexture
  */
 void glUploadTex(GLenum target, GLenum format, GLenum type,
-                 const void *data, int stride,
+                 const void *dataptr, int stride,
                  int x, int y, int w, int h, int slice) {
+  const uint8_t *data = dataptr;
   int y_max = y + h;
   if (w <= 0 || h <= 0) return;
   if (slice <= 0)
@@ -473,7 +473,7 @@
  * \param format OpenGL format of data
  * \param type OpenGL type of data
- * \param data data to upload
+ * \param dataptr data to upload
  * \param stride data stride
  * \param x x offset in texture